pub fn parse_file_full(file: &SourceFile) -> Option<ParseResult>Expand description
Detect language from file extension and parse, returning model + tree.
pub fn parse_file_full(file: &SourceFile) -> Option<ParseResult>Detect language from file extension and parse, returning model + tree.